@@ -1,5 +1,7 @@
 _base_ = ['./oriented_rcnn_r50_fpn_1x_dota_le90.py']
 
+pretrained = 'https://github.com/SwinTransformer/storage/releases/download/v1.0.0/swin_tiny_patch4_window7_224.pth'  # noqa
+
 model = dict(
     backbone=dict(
         _delete_=True,
@@ -18,10 +20,7 @@ model = dict(
         out_indices=(0, 1, 2, 3),
         with_cp=False,
         convert_weights=True,
-        init_cfg=dict(
-            type='Pretrained',
-            checkpoint='torch/hub/checkpoints/'
-            'swin_tiny_patch4_window7_224.pth')),
+        init_cfg=dict(type='Pretrained', checkpoint=pretrained)),
     neck=dict(
         _delete_=True,
         type='FPN',
