@@ -1,9 +1,9 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-from .assigners import (ATSSKldAssigner, ConvexAssigner, MaxConvexIoUAssigner,
-                        SASAssigner)
+from .assigners import (ATSSKldAssigner, ATSSObbAssigner, ConvexAssigner,
+                        MaxConvexIoUAssigner, SASAssigner)
 from .builder import build_assigner, build_bbox_coder, build_sampler
-from .coder import (DeltaXYWHAHBBoxCoder, DeltaXYWHAOBBoxCoder, GVFixCoder,
-                    GVRatioCoder, MidpointOffsetCoder)
+from .coder import (CSLCoder, DeltaXYWHAHBBoxCoder, DeltaXYWHAOBBoxCoder,
+                    GVFixCoder, GVRatioCoder, MidpointOffsetCoder)
 from .iou_calculators import RBboxOverlaps2D, rbbox_overlaps
 from .samplers import RRandomSampler
 from .transforms import (bbox_mapping_back, gaussian2bbox, gt2gaussian,
@@ -19,5 +19,6 @@ __all__ = [
     'DeltaXYWHAHBBoxCoder', 'MidpointOffsetCoder', 'GVFixCoder',
     'GVRatioCoder', 'ConvexAssigner', 'MaxConvexIoUAssigner', 'SASAssigner',
     'ATSSKldAssigner', 'gaussian2bbox', 'gt2gaussian', 'GaussianMixture',
-    'build_assigner', 'build_bbox_coder', 'build_sampler', 'bbox_mapping_back'
+    'build_assigner', 'build_bbox_coder', 'build_sampler', 'bbox_mapping_back',
+    'CSLCoder', 'ATSSObbAssigner'
 ]
