@@ -6,6 +6,7 @@ from .r3det import R3Det
 from .redet import ReDet
 from .roi_transformer import RoITransformer
 from .rotate_faster_rcnn import RotatedFasterRCNN
+from .rotated_fcos import RotatedFCOS
 from .rotated_reppoints import RotatedRepPoints
 from .rotated_retinanet import RotatedRetinaNet
 from .s2anet import S2ANet
@@ -16,5 +17,5 @@ __all__ = [
     'RotatedRetinaNet', 'RotatedFasterRCNN', 'OrientedRCNN', 'RoITransformer',
     'GlidingVertex', 'ReDet', 'R3Det', 'S2ANet', 'RotatedRepPoints',
     'RotatedBaseDetector', 'RotatedTwoStageDetector',
-    'RotatedSingleStageDetector'
+    'RotatedSingleStageDetector', 'RotatedFCOS'
 ]
